==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="43"/>
        <source>WildMidi Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="45"/>
        <source>Midi Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="100"/>
        <source>About WildMidi Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="101"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="102"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="103"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished">Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Sample rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <source>Enhanced resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Reverberation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="43"/>
        <source>WildMidi Plugin</source>
        <translation>WildMidi Module</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="45"/>
        <source>Midi Files</source>
        <translation>Midi Bestanden</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="100"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Over de WildMidi Audio Module</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="101"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>WildMidi Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="102"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Deze plugin faciliteert in het afspelen van midi bestanden, gebruikmakend van de WildMidi bibliotheek</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="103"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>WildMidi Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Instrument instellingen:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Sample frequentie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Verbeterde resampling</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Galm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation></translation>
    </message>
</context>
</TS>
